(* sig CHECK *)
(** Provides functions for checking types of terms, kinds of type operators and wellformedness of kinds. *)

type result = Surr.env * (Surr.env * Exp.exp)

exception Fail of string


(** [chk] is the top-level function of checking a term [t] against a type [A] *)
val chk : Clos.clos * Clos.clos -> result
(** [chk ((thL, gL), t), ((thR, gR), A) = (thR', (thL', e))] *) 

(** [chkKind] is the top-level function of checking wellformedness of a kind.
  Typical usage: [chkKind (kappa);] (the result is ignored) *)
val chkKind : Exp.exp -> result

(** [chkType] is the top-level function for checking wellformedness of a type.
  Typical usage: [chkType (tauCl);] (the result is ignored) *) 
val chkType : Clos.clos -> result

(** [chkType'] is a silent version of [chkType] *)
val chkType': Clos.clos -> result

(** [chkConstr] is the pendant to [chkType] for type operators.
  Typical usage: [chkConstr (tauCl, kappa);] (the result is ignored) *)
val chkConstr : Clos.clos * Exp.exp -> result
